@@ -29,7 +29,7 @@ from lava_test.core.tests import Test
 DEFAULT_OPTIONS = ""
 
 INSTALLSTEPS = ['git clone git://git.linaro.org/tools/pm-qa.git',
-                'cd pm-qa && make clean && make all']
+                'cd pm-qa && make -C utils']
 RUNSTEPS = ['cd pm-qa && make check $(OPTIONS)']
 DEPS = ['git-core', 'linux-libc-dev', 'build-essential']
 
